package com.bizmatics.controller.web;


import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.model.vo.DevopsWorkOrderDetailsVo;
import com.bizmatics.model.vo.DevopsWorkOrderListVo;
import com.bizmatics.model.vo.DevopsWorkOrderVo;
import com.bizmatics.service.DevopsWorkOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 运维管理-工单管理
 *
 * @author ya
 * @since 2021-10-21
 */
@RestController
@RequestMapping("/devopsWorkOrder")
public class DevopsWorkOrderController {

    @Autowired
    private DevopsWorkOrderService devopsWorkOrderService;

    /**
     * 运维管理-工单管理-新增
     *
     * @param devopsWorkOrderVo
     * @return
     */
    @GetMapping("devopsWorkOrderAdd")
    public ApiResult<Void> devopsWorkOrderAdd(@RequestBody DevopsWorkOrderVo devopsWorkOrderVo) {
        devopsWorkOrderService.devopsWorkOrderAdd(devopsWorkOrderVo);
        return ApiResult.success();
    }

    /**
     * 运维管理-工单管理-修改
     *
     * @param devopsWorkOrderVo
     * @return
     */
    @GetMapping("devopsWorkOrderUpdate")
    public ApiResult<Void> devopsWorkOrderUpdate(@RequestBody DevopsWorkOrderVo devopsWorkOrderVo) {
        devopsWorkOrderService.devopsWorkOrderUpdate(devopsWorkOrderVo);
        return ApiResult.success();
    }


    /**
     * 运维管理-工单管理-撤销
     *
     * @param id 工单ID
     * @return
     */
    @GetMapping("devopsWorkOrderDel")
    public ApiResult<Void> devopsWorkOrderDel(@RequestParam Integer id
    ) {
        devopsWorkOrderService.devopsWorkOrderDel(id);
        return ApiResult.success();
    }

    /**
     * 运维管理-工单管理-设备注销
     *
     * @param inspectionDeviceId 巡检设备ID
     * @return
     */
    @GetMapping("devopsOrderDeviceDel")
    public ApiResult<Void> devopsOrderDeviceDel(@RequestParam Integer inspectionDeviceId
    ) {
        devopsWorkOrderService.devopsOrderDeviceDel(inspectionDeviceId);
        return ApiResult.success();
    }

    /**
     * 运维管理-工单管理-人员注销
     *
     * @param inspectorsId 人员ID
     * @return
     */
    @GetMapping("devopsOrderInspectorsDel")
    public ApiResult<Void> devopsOrderInspectorsDel(@RequestParam Integer inspectorsId
    ) {
        devopsWorkOrderService.devopsOrderInspectorsDel(inspectorsId);
        return ApiResult.success();
    }


    /**
     * 运维管理-工单管理-列表查询
     *
     * @param generationMode  生成方式（1 巡检计划，2 现场提交，3 后台新增，4 其他）
     * @param workOrderStatus 工单状态（1 待抢单，2 待指派，3 待接单，4 待处理，5 待关单，6 已完成）
     * @param inspectorsId    人员ID
     * @param size            页数
     * @param current         条数
     * @return
     */
    @GetMapping("devopsWorkOrderList")
    public ApiResult<CommonPage<DevopsWorkOrderListVo>> devopsWorkOrderList(@RequestParam(value = "generationMode", required = false, defaultValue = "0") Integer generationMode,
                                                                            @RequestParam(value = "workOrderStatus", required = false, defaultValue = "0") Integer workOrderStatus,
                                                                            @RequestParam(value = "inspectorsId", required = false, defaultValue = "0") Integer inspectorsId,
                                                                            @RequestParam(value = "inspectorsId", required = false, defaultValue = "0") Integer siteId,
                                                                            @RequestParam(value = "size", required = false, defaultValue = "1") Integer size,
                                                                            @RequestParam(value = "current", required = false, defaultValue = "15") Integer current
    ) {
        return ApiResult.success(devopsWorkOrderService.devopsWorkOrderList(generationMode, workOrderStatus, siteId, inspectorsId, size, current));
    }

    /**
     * 运维管理-工单管理-详情查询
     *
     * @param id 工单ID
     * @return
     */
    @GetMapping("devopsWorkOrderDetails")
    public ApiResult<List<DevopsWorkOrderDetailsVo>> devopsWorkOrderDetails(@RequestParam Integer id
    ) {

        return ApiResult.success(devopsWorkOrderService.devopsWorkOrderDetails(id));
    }



}

