package com.bizmatics.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.common.mvc.base.AbstractCrudService;
import com.bizmatics.model.Device;
import com.bizmatics.model.DeviceAnalogVariableList;
import com.bizmatics.model.TemplateData;
import com.bizmatics.model.system.SysUser;
import com.bizmatics.model.vo.DeviceAnalogVariableListVo;
import com.bizmatics.persistence.mapper.DeviceAnalogVariableListMapper;
import com.bizmatics.service.DeviceAnalogVariableListService;
import com.bizmatics.service.DeviceService;
import com.bizmatics.service.util.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 设备变量列表 服务实现类
 * </p>
 *
 * @author ya
 * @since 2021-09-24
 */
@Service
public class DeviceAnalogVariableListServiceImpl extends AbstractCrudService<DeviceAnalogVariableListMapper, DeviceAnalogVariableList> implements DeviceAnalogVariableListService {
    @Autowired
    private DeviceAnalogVariableListService deviceAnalogVariableListService;
    @Autowired
    private DeviceService deviceService;

    @Override
    public void variableListAdd(DeviceAnalogVariableList deviceAnalogVariableList) {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        deviceAnalogVariableList.setCreateTime(new Date());
        deviceAnalogVariableList.setCreator(user.getUserName());
        deviceAnalogVariableList.setStatus(1);
        this.save(deviceAnalogVariableList);
    }

    @Override
    public void variableListUpdate(DeviceAnalogVariableList deviceAnalogVariableList) {
        this.updateById(deviceAnalogVariableList);
    }

    @Override
    public void variableListDel(int id) {
        DeviceAnalogVariableList deviceAnalogVariableList = new DeviceAnalogVariableList();
        deviceAnalogVariableList.setId(id);
        deviceAnalogVariableList.setStatus(0);
        this.updateById(deviceAnalogVariableList);
    }

    @Override
    public CommonPage<DeviceAnalogVariableList> variableList(String deviceCode, String screen, int size, int current) {
        IPage<DeviceAnalogVariableList> page = new Page<DeviceAnalogVariableList>(size, current);
        LambdaQueryWrapper<DeviceAnalogVariableList> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(DeviceAnalogVariableList::getDeviceCode, deviceCode).eq(DeviceAnalogVariableList::getStatus, 1);
        if (screen != null && !screen.equals("")) {
            queryWrapper.and(wq -> wq
                    .like(DeviceAnalogVariableList::getVariableName, screen)
                    .or()
                    .like(DeviceAnalogVariableList::getVariableCoding, screen));
        }

        page = this.page(page, queryWrapper);
        this.ToCommonPage(page);
        return new CommonPage<>(page.getRecords(), page.getTotal(), page.getCurrent(), page.getSize());
    }

    @Override
    public CommonPage<DeviceAnalogVariableList> variableListone(DeviceAnalogVariableListVo deviceAnalogVariableListVo){
        int start_current=(deviceAnalogVariableListVo.getSize()-1)*deviceAnalogVariableListVo.getCurrent();
        List<DeviceAnalogVariableList> deviceAnalogVariableListOne =  baseMapper.variableList(deviceAnalogVariableListVo.getSiteId(),deviceAnalogVariableListVo.getId(),
                deviceAnalogVariableListVo.getVariableName(), null, null,deviceAnalogVariableListVo.getDataArea());
        int total=0;
        if (deviceAnalogVariableListOne.size()>0){
            total= deviceAnalogVariableListOne.size();
        }
        List<DeviceAnalogVariableList> deviceAnalogVariableList =  baseMapper.variableList(deviceAnalogVariableListVo.getSiteId(),deviceAnalogVariableListVo.getId(),
                deviceAnalogVariableListVo.getVariableName(), start_current, deviceAnalogVariableListVo.getCurrent(),deviceAnalogVariableListVo.getDataArea());
        return new CommonPage<>(deviceAnalogVariableList, total, deviceAnalogVariableListVo.getCurrent(), deviceAnalogVariableListVo.getSize());
    }


}
