package com.bizmatics.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.bizmatics.common.core.util.Arith;
import com.bizmatics.common.core.util.DateUtils;
import com.bizmatics.common.mvc.base.AbstractCrudService;
import com.bizmatics.common.spring.util.JsonUtils;
import com.bizmatics.model.GroupingList;
import com.bizmatics.model.HadSiteStatic;
import com.bizmatics.model.HtAnalogData;
import com.bizmatics.model.vo.DataManagementVO;
import com.bizmatics.model.vo.HtAnalogDataVo;
import com.bizmatics.persistence.mapper.HtAnalogDataMapper;
import com.bizmatics.service.HadSiteStaticService;
import com.bizmatics.service.HtAnalogDataService;
import com.bizmatics.service.util.SecurityUtils;
import com.bizmatics.service.vo.*;
import com.fasterxml.jackson.core.type.TypeReference;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.swing.plaf.PanelUI;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.*;


/**
 * @author yq
 * @date 2021/7/20 16:49
 */
@Service
public class HtAnalogDataServiceImpl extends AbstractCrudService<HtAnalogDataMapper, HtAnalogData> implements HtAnalogDataService {


    @Autowired
    private HadSiteStaticService hadSiteStaticService;

    @Override
    public HadCountVO selectCount() {
        HadCountVO hadCountVO = new HadCountVO();
        Integer userId = SecurityUtils.getLoginUser().getUser().getUserId().intValue();
        Date date = new Date();
        hadCountVO.setDayCount(hadSiteStaticService.getCount(userId, DateUtils.getDayStartTime(date), date, null));
        hadCountVO.setMonthCount(hadSiteStaticService.getCount(userId, DateUtils.getFirstDayOfMonth(date), date, null));
        hadCountVO.setYearCount(hadSiteStaticService.getCount(userId, DateUtils.getBeginDayOfYear(date), date, null));
        return hadCountVO;
    }

    @Override
    public List<CommonIcoVO> selectTrendByDate(Integer siteId) {
        Integer userId = SecurityUtils.getLoginUser().getUser().getUserId().intValue();
        Date date = new Date();
        Date sTime = DateUtils.getDayStartTime(date);
        Date eTime = DateUtils.getDayEndTime(date);
        Date ysTime = DateUtils.addDays(sTime, -1);
        Date yeTime = DateUtils.addDays(eTime, -1);
        List<CommonIcoVO> list = new ArrayList<>();
        if (null != siteId) {
            list.add(getTreedBySite("昨日", siteId, ysTime, yeTime));
            list.add(getTreedBySite("今日", siteId, sTime, eTime));
        } else {
            list.add(getTrendOne("昨日", userId, ysTime, yeTime));
            list.add(getTrendOne("今日", userId, sTime, eTime));
        }
        return list;
    }


    public CommonIcoVO getTrendOne(String name, Integer userId, Date startTime, Date endTime) {
        List<HadSiteStatic> list = hadSiteStaticService.list(null, startTime, endTime, userId);
        List<Object> objects = new ArrayList<>();
        objects.add(0.0);
        List<Object> dates = new ArrayList<>();
        dates.add("00:00:00");
        for (int i = 2; i < 24; i += 2) {
            //结束时间
            Date hours = DateUtils.setHours(startTime, i);
            startTime = hours;
            dates.add(DateUtils.getTime(hours));
            Double hourCount = 0.00;
            for (HadSiteStatic hadSiteStatic : list) {
                CommonIcoVO commonIcoVO = JsonUtils.fromJson(hadSiteStatic.getLoadIco(), CommonIcoVO.class);
                List<Double> dataList = (List<Double>) commonIcoVO.getList();
                hourCount += dataList.get(i / 2);
            }
            objects.add(Arith.div(hourCount, 1, 2));
        }
        return CommonIcoVO.builder().name(name).list(objects).listDate(dates).build();
    }

    CommonIcoVO getTreedBySite(String name, Integer siteId, Date startTime, Date endTime) {
        Date sTime = DateUtils.getDayStartTime(startTime);
        Date eTime = DateUtils.getDayEndTime(endTime);
        HadSiteStatic hadSiteStatic = hadSiteStaticService.oneBySite(siteId, sTime, eTime);
        CommonIcoVO commonIcoVO = null;
        if (null != hadSiteStatic) {
            commonIcoVO = JsonUtils.fromJson(hadSiteStatic.getLoadIco(), CommonIcoVO.class);
            commonIcoVO.setName(name);
        } else {
            List<Object> objects = new ArrayList<>();
            objects.add(0.0);
            List<Object> dates = new ArrayList<>();
            dates.add("00:00:00");
            for (int i = 2; i < 24; i += 2) {
                //结束时间
                Date hours = DateUtils.setHours(startTime, i);
                objects.add(0.0);
                startTime = hours;
                dates.add(DateUtils.getTime(hours));
            }
            commonIcoVO = CommonIcoVO.builder().name(name).list(objects).listDate(dates).build();
        }
        return commonIcoVO;
    }

    @Override
    public List<CommonIcoVO> selectTrendByMonth() {
        Date date = new Date();
        Integer userId = SecurityUtils.getLoginUser().getUser().getUserId().intValue();
        List<CommonIcoVO> list = new ArrayList<>();
        list.add(selectTreedMonthOne(DateUtils.getLastDayOfMonth(DateUtils.addMonths(date, -1)), userId, "上月趋势图"));
        list.add(selectTreedMonthOne(DateUtils.getLastDayOfMonth(date), userId, "当月趋势图"));
        return list;
    }

    public CommonIcoVO selectTreedMonthOne(Date date, Integer userId, String name) {
        List<Object> objects = new ArrayList<>();
        List<Object> dateList = new ArrayList<>();
        for (int i = 1; i <= Integer.parseInt(DateUtils.getDay(date)); i++) {
            Date setDays = DateUtils.setDays(date, i);
            Date dayStartTime = DateUtils.getDayStartTime(setDays);
            Date dayEndTime = DateUtils.getDayEndTime(setDays);
            objects.add(hadSiteStaticService.getCount(userId, dayStartTime, dayEndTime, null));
            dateList.add(DateUtils.getDay(setDays));
        }
        return CommonIcoVO.builder().name(name).list(objects).listDate(dateList).build();
    }

    @Override
    public HadCountVO getCountBySite(Integer siteId) {
        Integer userId = SecurityUtils.getLoginUser().getUser().getUserId().intValue();
        Date date = new Date();
        //当日开始时间
        Date firstDayOfDate = DateUtils.getDayStartTime(date);
        //当月开始时间
        Date firstDayOfMonth = DateUtils.getFirstDayOfMonth(date);
        //当年开始时间
        Date firstDayOfYear = DateUtils.getBeginDayOfYear(date);
        HadCountVO hadCountVO = new HadCountVO();
        hadCountVO.setDayCount(hadSiteStaticService.getCount(userId, DateUtils.getDayStartTime(date), date, siteId));
        hadCountVO.setMonthCount(hadSiteStaticService.getCount(userId, DateUtils.getFirstDayOfMonth(date), date, siteId));
        hadCountVO.setYearCount(hadSiteStaticService.getCount(userId, DateUtils.getBeginDayOfYear(date), date, siteId));
        hadCountVO.setLastDayCount(hadSiteStaticService.getCount(userId, DateUtils.addDays(firstDayOfDate, -1), DateUtils.addDays(date, -1), siteId));
        hadCountVO.setLastMonthCount(hadSiteStaticService.getCount(userId, DateUtils.addMonths(firstDayOfMonth, -1), DateUtils.addMonths(date, -1), siteId));
        hadCountVO.setLastYearCount(hadSiteStaticService.getCount(userId, DateUtils.addYears(firstDayOfYear, -1), DateUtils.addYears(date, -1), siteId));
        hadCountVO.setDayRadio(Optional.ofNullable(hadCountVO.getDayCount())
                .filter(dayCount -> 0.00 != dayCount)
                .map(dayCount -> Arith.div(hadCountVO.getLastDayCount(), dayCount))
                .orElse(0.00));
        hadCountVO.setMonthRadio(Optional.ofNullable(hadCountVO.getMonthCount())
                .filter(dayCount -> 0.00 != dayCount)
                .map(dayCount -> Arith.div(hadCountVO.getLastMonthCount(), dayCount))
                .orElse(0.00));
        hadCountVO.setYearRadio(Optional.ofNullable(hadCountVO.getYearCount())
                .filter(dayCount -> 0.00 != dayCount)
                .map(dayCount -> Arith.div(hadCountVO.getLastYearCount(), dayCount))
                .orElse(0.00));
        return hadCountVO;

    }


    @Override
    public TimeShareVO getTimeShare(Integer siteId, Integer type) {
        TimeShareVO timeShareVO = new TimeShareVO();
        Date date = new Date();
        if (0 == type) {
            HadSiteStatic hadSiteStatic = hadSiteStaticService.oneBySite(siteId, date, date);
            Optional.ofNullable(hadSiteStatic).ifPresent(hads -> JsonUtils.fromJson(hads.getTimeShare(), timeShareVO.getClass()));
        } else {
            List<HadSiteStatic> list = hadSiteStaticService.list(siteId, DateUtils.getFirstDayOfMonth(date), date);
            for (HadSiteStatic hadSiteStatic : list) {
                Optional.ofNullable(hadSiteStatic.getTimeShare())
                        .ifPresent(has -> {
                            TimeShareVO ts = JsonUtils.fromJson(has, TimeShareVO.class);
                            timeShareVO.setFlat(Arith.add(timeShareVO.getFlat(), ts.getFlat()));
                            timeShareVO.setPeak(Arith.add(timeShareVO.getPeak(), ts.getPeak()));
                            timeShareVO.setNeed(Arith.add(timeShareVO.getNeed(), ts.getNeed()));
                            timeShareVO.setGrain(Arith.add(timeShareVO.getGrain(), ts.getGrain()));
                        });
            }
        }
        return timeShareVO;
    }

    @Override
    public List<CommonIcoVO> getDemandIco(Integer siteId) {
        Date date = new Date();
        List<Object> maxList = new ArrayList<>();
        List<Object> minList = new ArrayList<>();
        List<Object> avgList = new ArrayList<>();
        List<Object> dateList = new ArrayList<>();
        List<HadSiteStatic> hadSiteStatics = hadSiteStaticService.list(siteId, DateUtils.getFirstDayOfMonth(date), date);
        for (int i = 1; i <= Integer.parseInt(DateUtils.getDay(date)); i++) {
            Date setDays = DateUtils.setDays(date, i);
            Date dayStartTime = DateUtils.getDayStartTime(setDays);
            Date dayEndTime = DateUtils.getDayEndTime(setDays);
            maxList.add(hadSiteStatics.stream()
                    .filter(hadSiteStatic -> DateUtils.isEffectiveDate(hadSiteStatic.getHadTime(), dayStartTime, dayEndTime)
                    ).findFirst().map(HadSiteStatic::getMaxDemand).orElse(0.00));
            minList.add(hadSiteStatics.stream()
                    .filter(hadSiteStatic -> DateUtils.isEffectiveDate(hadSiteStatic.getHadTime(), dayStartTime, dayEndTime)
                    ).findFirst().map(HadSiteStatic::getMinDemand).orElse(0.00));
            avgList.add(hadSiteStatics.stream()
                    .filter(hadSiteStatic -> DateUtils.isEffectiveDate(hadSiteStatic.getHadTime(), dayStartTime, dayEndTime)
                    ).findFirst().map(HadSiteStatic::getAvgDemand).orElse(0.00));
            dateList.add(DateUtils.getDay(setDays));
        }
        List<CommonIcoVO> list = new ArrayList<>();
        list.add(CommonIcoVO.builder().name("最大值").list(maxList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("最小值").list(minList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("平均值").list(avgList).listDate(dateList).build());
        return list;
    }

    @Override
    public List<CommonIcoVO> getElectricIco(Integer siteId, Date date) {
        List<Object> iaList = new ArrayList<>();
        iaList.add(0.00);
        List<Object> ibList = new ArrayList<>();
        ibList.add(0.00);
        List<Object> icList = new ArrayList<>();
        icList.add(0.00);
        List<Object> uaList = new ArrayList<>();
        uaList.add(0.00);
        List<Object> ubList = new ArrayList<>();
        ubList.add(0.00);
        List<Object> ucList = new ArrayList<>();
        ucList.add(0.00);
        List<Object> dateList = new ArrayList<>();
        dateList.add("00:00:00");
        HadSiteStatic hadSiteStatic = hadSiteStaticService.oneBySite(siteId, date, date);
        List<HtAnalogData> htList = Optional.ofNullable(hadSiteStatic)
                .map(HadSiteStatic::getHisIco)
                .map(his -> JsonUtils.fromJson(hadSiteStatic.getHisIco(), new TypeReference<List<HtAnalogData>>() {
                }))
                .orElse(null);
        for (int i = 2; i < 24; i += 2) {
            Date hours = DateUtils.setHours(date, i);
            date = hours;
            Date finalDate = date;
            Optional<HtAnalogData> htAnalogData = Optional.ofNullable(htList).flatMap(hts -> hts.stream()
                    .filter(hads -> DateUtils.isEffectiveDate(hads.getDataTime(), finalDate, hours))
                    .findFirst());
            iaList.add(htAnalogData.map(HtAnalogData::getIa).orElse(0.00));
            ibList.add(htAnalogData.map(HtAnalogData::getIb).orElse(0.00));
            icList.add(htAnalogData.map(HtAnalogData::getIc).orElse(0.00));
            uaList.add(htAnalogData.map(HtAnalogData::getUa).orElse(0.00));
            ubList.add(htAnalogData.map(HtAnalogData::getUb).orElse(0.00));
            ucList.add(htAnalogData.map(HtAnalogData::getUc).orElse(0.00));
            dateList.add(htAnalogData.map(HtAnalogData::getDataTime).map(s -> DateUtils.getTime(hours)).orElse(DateUtils.getTime(hours)));
        }
        List<CommonIcoVO> list = new ArrayList<>();
        list.add(CommonIcoVO.builder().name("IA").list(iaList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("IB").list(ibList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("IC").list(icList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("UA").list(uaList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("UB").list(ubList).listDate(dateList).build());
        list.add(CommonIcoVO.builder().name("UC").list(ucList).listDate(dateList).build());
        return list;
    }


    @Override
    public List<CommonIcoVO> yearOnYearList(DataManagementVO dataManagementVO) {
        List<HtAnalogDataVo> yearOnYearList = null;
        if (dataManagementVO.getType() == 1) {
            if (dataManagementVO.getValueCalculation() == 1) {
                yearOnYearList = baseMapper.yearOnYearOne(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 2) {
                yearOnYearList = baseMapper.dayMaxDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 3) {
                yearOnYearList = baseMapper.dayMinDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 4) {
                yearOnYearList = baseMapper.daySumDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            }
        } else if (dataManagementVO.getType() == 2) {
            if (dataManagementVO.getValueCalculation() == 1) {
                yearOnYearList = baseMapper.yearOnYearTwo(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 2) {
                yearOnYearList = baseMapper.monthMaxDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 3) {
                yearOnYearList = baseMapper.monthMinDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            } else if (dataManagementVO.getValueCalculation() == 4) {
                yearOnYearList = baseMapper.monthSumDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            }
        } else {
            yearOnYearList = baseMapper.yearOnYearThree(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
        }
        String[] arr = dataManagementVO.getDisplayField().split(",");
        List<Object> BusotList = new ArrayList<>();
        List<Object> COSList = new ArrayList<>();
        List<Object> COSaList = new ArrayList<>();
        List<Object> COSbList = new ArrayList<>();
        List<Object> COScList = new ArrayList<>();
        List<Object> DemandList = new ArrayList<>();
        List<Object> DevResetTimesList = new ArrayList<>();
        List<Object> DeviceTempList = new ArrayList<>();
        List<Object> EpnList = new ArrayList<>();
        List<Object> Epn1List = new ArrayList<>();
        List<Object> Epn2List = new ArrayList<>();
        List<Object> Epn3List = new ArrayList<>();
        List<Object> Epn4List = new ArrayList<>();
        List<Object> EppList = new ArrayList<>();
        List<Object> Epp1List = new ArrayList<>();
        List<Object> Epp2List = new ArrayList<>();
        List<Object> Epp3List = new ArrayList<>();
        List<Object> Epp4List = new ArrayList<>();
        List<Object> EqnList = new ArrayList<>();
        List<Object> EqpList = new ArrayList<>();
        List<Object> FList = new ArrayList<>();
        List<Object> I0List = new ArrayList<>();
        List<Object> I2List = new ArrayList<>();
        List<Object> IHaList = new ArrayList<>();
        List<Object> IHbList = new ArrayList<>();
        List<Object> IHcList = new ArrayList<>();
        List<Object> IaList = new ArrayList<>();
        List<Object> IbList = new ArrayList<>();
        List<Object> IcList = new ArrayList<>();
        List<Object> IrList = new ArrayList<>();
        List<Object> LastDayMDList = new ArrayList<>();
        List<Object> LastDayMDtList = new ArrayList<>();
        List<Object> PList = new ArrayList<>();
        List<Object> PaList = new ArrayList<>();
        List<Object> PbList = new ArrayList<>();
        List<Object> PcList = new ArrayList<>();
        List<Object> QList = new ArrayList<>();
        List<Object> QaList = new ArrayList<>();
        List<Object> QbList = new ArrayList<>();
        List<Object> QcList = new ArrayList<>();
        List<Object> SignalIntensityList = new ArrayList<>();
        List<Object> T1List = new ArrayList<>();
        List<Object> T2List = new ArrayList<>();
        List<Object> T3List = new ArrayList<>();
        List<Object> T4List = new ArrayList<>();
        List<Object> THDUaList = new ArrayList<>();
        List<Object> THDUbList = new ArrayList<>();
        List<Object> THDUcList = new ArrayList<>();
        List<Object> UaList = new ArrayList<>();
        List<Object> UabList = new ArrayList<>();
        List<Object> UbList = new ArrayList<>();
        List<Object> UbcList = new ArrayList<>();
        List<Object> UblU0List = new ArrayList<>();
        List<Object> UblU2List = new ArrayList<>();
        List<Object> UcList = new ArrayList<>();
        List<Object> UcaList = new ArrayList<>();
        List<Object> UdtList = new ArrayList<>();
        List<Object> UlList = new ArrayList<>();
        List<Object> UptList = new ArrayList<>();
        List<Object> freezingTimesList = new ArrayList<>();
        List<Object> UstList = new ArrayList<>();

        if (yearOnYearList.size() > 0) {
            for (int i = 0; i < yearOnYearList.size(); i++) {
                freezingTimesList.add(yearOnYearList.get(i).getFreezingTimes());
                if (Arrays.asList(arr).contains("Busot")) {
                    BusotList.add(yearOnYearList.get(i).getBusot());
                }
                if (Arrays.asList(arr).contains("Ust")) {
                    UstList.add(yearOnYearList.get(i).getUst());
                }
                if (Arrays.asList(arr).contains("Upt")) {
                    UptList.add(yearOnYearList.get(i).getUpt());
                }
                if (Arrays.asList(arr).contains("Ul")) {
                    UlList.add(yearOnYearList.get(i).getUl());
                }
                if (Arrays.asList(arr).contains("Udt")) {
                    UdtList.add(yearOnYearList.get(i).getUdt());
                }
                if (Arrays.asList(arr).contains("Uca")) {
                    UcaList.add(yearOnYearList.get(i).getUca());
                }
                if (Arrays.asList(arr).contains("Uc")) {
                    UcList.add(yearOnYearList.get(i).getUc());
                }
                if (Arrays.asList(arr).contains("UblU2")) {
                    UblU2List.add(yearOnYearList.get(i).getUblU2());
                }
                if (Arrays.asList(arr).contains("UblU0")) {
                    UblU0List.add(yearOnYearList.get(i).getUblU0());
                }
                if (Arrays.asList(arr).contains("Ubc")) {
                    UbcList.add(yearOnYearList.get(i).getUbc());
                }
                if (Arrays.asList(arr).contains("Ub")) {
                    UbList.add(yearOnYearList.get(i).getUb());
                }
                if (Arrays.asList(arr).contains("Uab")) {
                    UabList.add(yearOnYearList.get(i).getUab());
                }
                if (Arrays.asList(arr).contains("Ua")) {
                    UaList.add(yearOnYearList.get(i).getUa());
                }
                if (Arrays.asList(arr).contains("THDUc")) {
                    THDUcList.add(yearOnYearList.get(i).getTHDUc());
                }
                if (Arrays.asList(arr).contains("THDUb")) {
                    THDUbList.add(yearOnYearList.get(i).getTHDUb());
                }
                if (Arrays.asList(arr).contains("THDUa")) {
                    THDUaList.add(yearOnYearList.get(i).getTHDUa());
                }
                if (Arrays.asList(arr).contains("T4")) {
                    T4List.add(yearOnYearList.get(i).getT4());
                }
                if (Arrays.asList(arr).contains("T3")) {
                    T3List.add(yearOnYearList.get(i).getT3());
                }
                if (Arrays.asList(arr).contains("T2")) {
                    T2List.add(yearOnYearList.get(i).getT2());
                }
                if (Arrays.asList(arr).contains("T1")) {
                    T1List.add(yearOnYearList.get(i).getT1());
                }
                if (Arrays.asList(arr).contains("SignalIntensity")) {
                    SignalIntensityList.add(yearOnYearList.get(i).getSignalIntensity());
                }
                if (Arrays.asList(arr).contains("Qc")) {
                    QcList.add(yearOnYearList.get(i).getQc());
                }
                if (Arrays.asList(arr).contains("Qb")) {
                    QbList.add(yearOnYearList.get(i).getQb());
                }
                if (Arrays.asList(arr).contains("Qa")) {
                    QaList.add(yearOnYearList.get(i).getQa());
                }
                if (Arrays.asList(arr).contains("Q")) {
                    QList.add(yearOnYearList.get(i).getQ());
                }
                if (Arrays.asList(arr).contains("Pc")) {
                    PcList.add(yearOnYearList.get(i).getPc());
                }
                if (Arrays.asList(arr).contains("Pb")) {
                    PbList.add(yearOnYearList.get(i).getPb());
                }
                if (Arrays.asList(arr).contains("Pa")) {
                    PaList.add(yearOnYearList.get(i).getPa());
                }
                if (Arrays.asList(arr).contains("P")) {
                    PList.add(yearOnYearList.get(i).getP());
                }
                if (Arrays.asList(arr).contains("LastDayMDt")) {
                    LastDayMDtList.add(yearOnYearList.get(i).getLastDayMDt());
                }
                if (Arrays.asList(arr).contains("LastDayMD")) {
                    LastDayMDList.add(yearOnYearList.get(i).getLastDayMD());
                }
                if (Arrays.asList(arr).contains("Ir")) {
                    IrList.add(yearOnYearList.get(i).getIr());
                }
                if (Arrays.asList(arr).contains("Ic")) {
                    IcList.add(yearOnYearList.get(i).getIc());
                }
                if (Arrays.asList(arr).contains("Ib")) {
                    IbList.add(yearOnYearList.get(i).getIb());
                }
                if (Arrays.asList(arr).contains("Ia")) {
                    IaList.add(yearOnYearList.get(i).getIa());
                }
                if (Arrays.asList(arr).contains("IHc")) {
                    IHcList.add(yearOnYearList.get(i).getIHc());
                }
                if (Arrays.asList(arr).contains("IHb")) {
                    IHbList.add(yearOnYearList.get(i).getIHb());
                }
                if (Arrays.asList(arr).contains("IHa")) {
                    IHaList.add(yearOnYearList.get(i).getIHa());
                }
                if (Arrays.asList(arr).contains("I2")) {
                    I2List.add(yearOnYearList.get(i).getI2());
                }
                if (Arrays.asList(arr).contains("I0")) {
                    I0List.add(yearOnYearList.get(i).getI0());
                }
                if (Arrays.asList(arr).contains("F")) {
                    FList.add(yearOnYearList.get(i).getF());
                }
                if (Arrays.asList(arr).contains("Eqp")) {
                    EqpList.add(yearOnYearList.get(i).getEqp());
                }
                if (Arrays.asList(arr).contains("Eqn")) {
                    EqnList.add(yearOnYearList.get(i).getEqn());
                }
                if (Arrays.asList(arr).contains("Epp4")) {
                    Epp4List.add(yearOnYearList.get(i).getEpp4());
                }
                if (Arrays.asList(arr).contains("Epp3")) {
                    Epp3List.add(yearOnYearList.get(i).getEpp3());
                }
                if (Arrays.asList(arr).contains("Epp2")) {
                    Epp2List.add(yearOnYearList.get(i).getEpp2());
                }
                if (Arrays.asList(arr).contains("Epp1")) {
                    Epp1List.add(yearOnYearList.get(i).getEpp1());
                }
                if (Arrays.asList(arr).contains("Epp")) {
                    EppList.add(yearOnYearList.get(i).getEpp());
                }
                if (Arrays.asList(arr).contains("Epn4")) {
                    Epn4List.add(yearOnYearList.get(i).getEpn4());
                }
                if (Arrays.asList(arr).contains("Epn3")) {
                    Epn3List.add(yearOnYearList.get(i).getEpn3());
                }
                if (Arrays.asList(arr).contains("Epn2")) {
                    Epn2List.add(yearOnYearList.get(i).getEpn2());
                }
                if (Arrays.asList(arr).contains("Epn1")) {
                    Epn1List.add(yearOnYearList.get(i).getEpn1());
                }
                if (Arrays.asList(arr).contains("Epn")) {
                    EpnList.add(yearOnYearList.get(i).getEpn());
                }
                if (Arrays.asList(arr).contains("DeviceTemp")) {
                    DeviceTempList.add(yearOnYearList.get(i).getDeviceTemp());
                }
                if (Arrays.asList(arr).contains("DevResetTimes")) {
                    DevResetTimesList.add(yearOnYearList.get(i).getDevResetTimes());
                }
                if (Arrays.asList(arr).contains("Demand")) {
                    DemandList.add(yearOnYearList.get(i).getDemand());
                }
                if (Arrays.asList(arr).contains("COSc")) {
                    COScList.add(yearOnYearList.get(i).getCOSc());
                }
                if (Arrays.asList(arr).contains("COSb")) {
                    COSbList.add(yearOnYearList.get(i).getCOSb());
                }
                if (Arrays.asList(arr).contains("COSa")) {
                    COSaList.add(yearOnYearList.get(i).getCOSa());
                }
                if (Arrays.asList(arr).contains("COS")) {
                    COSList.add(yearOnYearList.get(i).getCos());
                }

            }

        }
        List<CommonIcoVO> list = new ArrayList<>();
        if (Arrays.asList(arr).contains("Busot")) {
            list.add(CommonIcoVO.builder().name("母线停电次数").list(BusotList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COS")) {
            list.add(CommonIcoVO.builder().name("三相功率因数").list(COSList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSa")) {
            list.add(CommonIcoVO.builder().name("A相功率因数").list(COSaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSb")) {
            list.add(CommonIcoVO.builder().name("B相功率因数").list(COSbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSc")) {
            list.add(CommonIcoVO.builder().name("C相功率因数").list(COScList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Demand")) {
            list.add(CommonIcoVO.builder().name("实时有功需量").list(DemandList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("DevResetTimes")) {
            list.add(CommonIcoVO.builder().name("设备复位次数").list(DevResetTimesList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("DeviceTemp")) {
            list.add(CommonIcoVO.builder().name("设备温度").list(DeviceTempList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn")) {
            list.add(CommonIcoVO.builder().name("三相反向有功电度").list(EpnList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn1")) {
            list.add(CommonIcoVO.builder().name("尖段反向有功电度").list(Epn1List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn2")) {
            list.add(CommonIcoVO.builder().name("峰段反向有功电度").list(Epn2List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn3")) {
            list.add(CommonIcoVO.builder().name("平段反向有功电度").list(Epn3List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn4")) {
            list.add(CommonIcoVO.builder().name("谷段反向有功电度").list(Epn4List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp")) {
            list.add(CommonIcoVO.builder().name("三相正向有功电度").list(EppList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp1")) {
            list.add(CommonIcoVO.builder().name("尖段正向有功电度").list(Epp1List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp2")) {
            list.add(CommonIcoVO.builder().name("峰段正向有功电度").list(Epp2List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp3")) {
            list.add(CommonIcoVO.builder().name("平段正向有功电度").list(Epp3List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp4")) {
            list.add(CommonIcoVO.builder().name("谷段正向有功电度").list(Epp4List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Eqn")) {
            list.add(CommonIcoVO.builder().name("三相反向无功电度").list(EqnList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Eqp")) {
            list.add(CommonIcoVO.builder().name("三相正向无功电度").list(EqpList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("F")) {
            list.add(CommonIcoVO.builder().name("频率").list(FList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("I0")) {
            list.add(CommonIcoVO.builder().name("零序电流").list(I0List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("I2")) {
            list.add(CommonIcoVO.builder().name("负序电流").list(I2List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHa")) {
            list.add(CommonIcoVO.builder().name("A相总谐波电流").list(IHaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHb")) {
            list.add(CommonIcoVO.builder().name("B相总谐波电流").list(IHbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHc")) {
            list.add(CommonIcoVO.builder().name("C相总谐波电流").list(IHcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ia")) {
            list.add(CommonIcoVO.builder().name("A相电流").list(IaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ib")) {
            list.add(CommonIcoVO.builder().name("B相电流").list(IbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ic")) {
            list.add(CommonIcoVO.builder().name("C相电流").list(IcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ir")) {
            list.add(CommonIcoVO.builder().name("剩余电流").list(IrList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("LastDayMD")) {
            list.add(CommonIcoVO.builder().name("昨日有功最大需量").list(LastDayMDList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("LastDayMDt")) {
            list.add(CommonIcoVO.builder().name("昨日有功最大需量发生时间").list(LastDayMDtList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("P")) {
            list.add(CommonIcoVO.builder().name("三相总有功功率").list(PList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pa")) {
            list.add(CommonIcoVO.builder().name("A相有功功率").list(PaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pb")) {
            list.add(CommonIcoVO.builder().name("B相有功功率").list(PbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pc")) {
            list.add(CommonIcoVO.builder().name("C相有功功率").list(PcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Q")) {
            list.add(CommonIcoVO.builder().name("三相总无功功率").list(QList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qa")) {
            list.add(CommonIcoVO.builder().name("A相无功功率").list(QaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qb")) {
            list.add(CommonIcoVO.builder().name("B相无功功率").list(QbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qc")) {
            list.add(CommonIcoVO.builder().name("C相无功功率").list(QcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("SignalIntensity")) {
            list.add(CommonIcoVO.builder().name("信号强度").list(SignalIntensityList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T1")) {
            list.add(CommonIcoVO.builder().name("第1路温度").list(T1List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T2")) {
            list.add(CommonIcoVO.builder().name("第2路温度").list(T2List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T3")) {
            list.add(CommonIcoVO.builder().name("第3路温度").list(T3List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T4")) {
            list.add(CommonIcoVO.builder().name("第4路温度").list(T4List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUa")) {
            list.add(CommonIcoVO.builder().name("A相电压THD").list(THDUaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUb")) {
            list.add(CommonIcoVO.builder().name("B相电压THD").list(THDUbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUc")) {
            list.add(CommonIcoVO.builder().name("C相电压THD").list(THDUcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ua")) {
            list.add(CommonIcoVO.builder().name("A相电压").list(UaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uab")) {
            list.add(CommonIcoVO.builder().name("AB线电压").list(UabList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ub")) {
            list.add(CommonIcoVO.builder().name("B相电压").list(UbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ubc")) {
            list.add(CommonIcoVO.builder().name("BC线电压").list(UbcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("UblU0")) {
            list.add(CommonIcoVO.builder().name("零序电压不平衡度").list(UblU0List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("UblU2")) {
            list.add(CommonIcoVO.builder().name("负序电压不平衡度").list(UblU2List).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uc")) {
            list.add(CommonIcoVO.builder().name("C相电压").list(UcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uca")) {
            list.add(CommonIcoVO.builder().name("CA线电压").list(UcaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Udt")) {
            list.add(CommonIcoVO.builder().name("电压暂降次数").list(UdtList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ul")) {
            list.add(CommonIcoVO.builder().name("线路侧电压").list(UlList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Upt")) {
            list.add(CommonIcoVO.builder().name("电压暂升次数").list(UptList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("freezingTime")) {
            list.add(CommonIcoVO.builder().name("电压短时中断次数").list(freezingTimesList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ust")) {
            list.add(CommonIcoVO.builder().name("冻结时间").list(UstList).listDate(freezingTimesList).build());
        }
        return list;
    }


    @Override
    public List<CommonIcoOneVO> ringRatioList(DataManagementVO dataManagementVO) {
        SimpleDateFormat sf = null;
        SimpleDateFormat sfOne = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<HtAnalogDataVo> currentPeriodRingRatioList = null;
        List<HtAnalogDataVo> lastPeriodRingRatioList = null;
        List<Object> BusotList = new ArrayList<>();
        List<Object> BusotListOne = new ArrayList<>();
        List<Object> COSList = new ArrayList<>();
        List<Object> COSListOne = new ArrayList<>();
        List<Object> COSaList = new ArrayList<>();
        List<Object> COSaListOne = new ArrayList<>();
        List<Object> COSbList = new ArrayList<>();
        List<Object> COSbListOne = new ArrayList<>();
        List<Object> COScList = new ArrayList<>();
        List<Object> COScListOne = new ArrayList<>();
        List<Object> DemandList = new ArrayList<>();
        List<Object> DemandListOne = new ArrayList<>();
        List<Object> DevResetTimesList = new ArrayList<>();
        List<Object> DevResetTimesListOne = new ArrayList<>();
        List<Object> DeviceTempList = new ArrayList<>();
        List<Object> DeviceTempListOne = new ArrayList<>();
        List<Object> EpnList = new ArrayList<>();
        List<Object> EpnListOne = new ArrayList<>();
        List<Object> Epn1List = new ArrayList<>();
        List<Object> Epn1ListOne = new ArrayList<>();
        List<Object> Epn2List = new ArrayList<>();
        List<Object> Epn2ListOne = new ArrayList<>();
        List<Object> Epn3List = new ArrayList<>();
        List<Object> Epn3ListOne = new ArrayList<>();
        List<Object> Epn4List = new ArrayList<>();
        List<Object> Epn4ListOne = new ArrayList<>();
        List<Object> EppList = new ArrayList<>();
        List<Object> EppListOne = new ArrayList<>();
        List<Object> Epp1List = new ArrayList<>();
        List<Object> Epp1ListOne = new ArrayList<>();
        List<Object> Epp2List = new ArrayList<>();
        List<Object> Epp2ListOne = new ArrayList<>();
        List<Object> Epp3List = new ArrayList<>();
        List<Object> Epp3ListOne = new ArrayList<>();
        List<Object> Epp4List = new ArrayList<>();
        List<Object> Epp4ListOne = new ArrayList<>();
        List<Object> EqnList = new ArrayList<>();
        List<Object> EqnListOne = new ArrayList<>();
        List<Object> EqpList = new ArrayList<>();
        List<Object> EqpListOne = new ArrayList<>();
        List<Object> FList = new ArrayList<>();
        List<Object> FListOne = new ArrayList<>();
        List<Object> I0List = new ArrayList<>();
        List<Object> I0ListOne = new ArrayList<>();
        List<Object> I2List = new ArrayList<>();
        List<Object> I2ListOne = new ArrayList<>();
        List<Object> IHaList = new ArrayList<>();
        List<Object> IHaListOne = new ArrayList<>();
        List<Object> IHbList = new ArrayList<>();
        List<Object> IHbListOne = new ArrayList<>();
        List<Object> IHcList = new ArrayList<>();
        List<Object> IHcListOne = new ArrayList<>();
        List<Object> IaList = new ArrayList<>();
        List<Object> IaListOne = new ArrayList<>();
        List<Object> IbList = new ArrayList<>();
        List<Object> IbListOne = new ArrayList<>();
        List<Object> IcList = new ArrayList<>();
        List<Object> IcListOne = new ArrayList<>();
        List<Object> IrList = new ArrayList<>();
        List<Object> IrListOne = new ArrayList<>();
        List<Object> LastDayMDList = new ArrayList<>();
        List<Object> LastDayMDListOne = new ArrayList<>();
        List<Object> LastDayMDtList = new ArrayList<>();
        List<Object> LastDayMDtListOne = new ArrayList<>();
        List<Object> PList = new ArrayList<>();
        List<Object> PListOne = new ArrayList<>();
        List<Object> PaList = new ArrayList<>();
        List<Object> PaListOne = new ArrayList<>();
        List<Object> PbList = new ArrayList<>();
        List<Object> PbListOne = new ArrayList<>();
        List<Object> PcList = new ArrayList<>();
        List<Object> PcListOne = new ArrayList<>();
        List<Object> QList = new ArrayList<>();
        List<Object> QListOne = new ArrayList<>();
        List<Object> QaList = new ArrayList<>();
        List<Object> QaListOne = new ArrayList<>();
        List<Object> QbList = new ArrayList<>();
        List<Object> QbListOne = new ArrayList<>();
        List<Object> QcList = new ArrayList<>();
        List<Object> QcListOne = new ArrayList<>();
        List<Object> SignalIntensityList = new ArrayList<>();
        List<Object> SignalIntensityListOne = new ArrayList<>();
        List<Object> T1List = new ArrayList<>();
        List<Object> T1ListOne = new ArrayList<>();
        List<Object> T2List = new ArrayList<>();
        List<Object> T2ListOne = new ArrayList<>();
        List<Object> T3List = new ArrayList<>();
        List<Object> T3ListOne = new ArrayList<>();
        List<Object> T4List = new ArrayList<>();
        List<Object> T4ListOne = new ArrayList<>();
        List<Object> THDUaList = new ArrayList<>();
        List<Object> THDUaListOne = new ArrayList<>();
        List<Object> THDUbList = new ArrayList<>();
        List<Object> THDUbListOne = new ArrayList<>();
        List<Object> THDUcList = new ArrayList<>();
        List<Object> THDUcListOne = new ArrayList<>();
        List<Object> UaList = new ArrayList<>();
        List<Object> UaListOne = new ArrayList<>();
        List<Object> UabList = new ArrayList<>();
        List<Object> UabListOne = new ArrayList<>();
        List<Object> UbList = new ArrayList<>();
        List<Object> UbListOne = new ArrayList<>();
        List<Object> UbcList = new ArrayList<>();
        List<Object> UbcListOne = new ArrayList<>();
        List<Object> UblU0List = new ArrayList<>();
        List<Object> UblU0ListOne = new ArrayList<>();
        List<Object> UblU2List = new ArrayList<>();
        List<Object> UblU2ListOne = new ArrayList<>();
        List<Object> UcList = new ArrayList<>();
        List<Object> UcListOne = new ArrayList<>();
        List<Object> UcaList = new ArrayList<>();
        List<Object> UcaListOne = new ArrayList<>();
        List<Object> UdtList = new ArrayList<>();
        List<Object> UdtListOne = new ArrayList<>();
        List<Object> UlList = new ArrayList<>();
        List<Object> UlListOne = new ArrayList<>();
        List<Object> UptList = new ArrayList<>();
        List<Object> UptListOne = new ArrayList<>();
        List<Object> freezingTimesList = new ArrayList<>();
        List<Object> freezingTimesListOne = new ArrayList<>();
        List<Object> UstList = new ArrayList<>();
        List<Object> UstListOne = new ArrayList<>();
//        List<Object> bottomTimeList = new ArrayList<>();        List<Object> bottomTimeListOne = new ArrayList<>();
        String[] arr = dataManagementVO.getDisplayField().split(",");
        long startLong = DateUtils.toDate(DateUtils.toLocalDateTime(dataManagementVO.getStartTime(), "yyyy-MM-dd HH:mm:ss")).getTime();
        long endLong = DateUtils.toDate(DateUtils.toLocalDateTime(dataManagementVO.getEndTime(), "yyyy-MM-dd HH:mm:ss")).getTime();
        long interval = (endLong - startLong) / 13;
        String lastPeriodStartTime = sfOne.format(new Date(startLong - (interval * 14)));
        if (dataManagementVO.getType() == 1) {
//            sf = new SimpleDateFormat("yyyy-MM-dd");
            if (dataManagementVO.getValueCalculation() == 1) {
                currentPeriodRingRatioList = baseMapper.yearOnYearOne(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.yearOnYearOne(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 2) {
                currentPeriodRingRatioList = baseMapper.dayMaxDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.dayMaxDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 3) {
                currentPeriodRingRatioList = baseMapper.dayMinDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.dayMinDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 4) {
                currentPeriodRingRatioList = baseMapper.daySumDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.daySumDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            }
        } else if (dataManagementVO.getType() == 2) {
//            sf = new SimpleDateFormat("yyyy-MM");
            if (dataManagementVO.getValueCalculation() == 1) {
                currentPeriodRingRatioList = baseMapper.yearOnYearTwo(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.yearOnYearTwo(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 2) {
                currentPeriodRingRatioList = baseMapper.monthMaxDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.monthMaxDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 3) {
                currentPeriodRingRatioList = baseMapper.monthMinDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.monthMinDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            } else if (dataManagementVO.getValueCalculation() == 4) {
                currentPeriodRingRatioList = baseMapper.monthSumDataList(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
                lastPeriodRingRatioList = baseMapper.monthSumDataList(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
            }
        } else {
            sf = new SimpleDateFormat("MM-dd HH:mm");
            currentPeriodRingRatioList = baseMapper.yearOnYearThree(dataManagementVO.getDeviceCode(), dataManagementVO.getStartTime(), dataManagementVO.getEndTime());
            lastPeriodRingRatioList = baseMapper.yearOnYearThree(dataManagementVO.getDeviceCode(), lastPeriodStartTime, dataManagementVO.getStartTime());
        }
//        for (int i = 1; i <= 14; i++) {
//            String bottomTime = sf.format(new Date(startLong + (interval * (i - 1))))+"/"+sf.format(new Date(startLong - (interval * (14-i+1))));
//            bottomTimeList.add(bottomTime);
//        }

        if (currentPeriodRingRatioList.size() > 0) {
            for (int i = 0; i < currentPeriodRingRatioList.size(); i++) {
                freezingTimesList.add(currentPeriodRingRatioList.get(i).getFreezingTimes() + "/" + lastPeriodRingRatioList.get(i).getFreezingTimes());
                if (Arrays.asList(arr).contains("Busot")) {
                    BusotList.add(currentPeriodRingRatioList.get(i).getBusot());
                    BusotListOne.add(lastPeriodRingRatioList.get(i).getBusot());
                }
                if (Arrays.asList(arr).contains("Ust")) {
                    UstList.add(currentPeriodRingRatioList.get(i).getUst());
                    UstListOne.add(lastPeriodRingRatioList.get(i).getUst());
                }
                if (Arrays.asList(arr).contains("Upt")) {
                    UptList.add(currentPeriodRingRatioList.get(i).getUpt());
                    UptListOne.add(lastPeriodRingRatioList.get(i).getUpt());
                }
                if (Arrays.asList(arr).contains("Ul")) {
                    UlList.add(currentPeriodRingRatioList.get(i).getUl());
                    UlListOne.add(lastPeriodRingRatioList.get(i).getUl());
                }
                if (Arrays.asList(arr).contains("Udt")) {
                    UdtList.add(currentPeriodRingRatioList.get(i).getUdt());
                    UdtListOne.add(lastPeriodRingRatioList.get(i).getUdt());
                }
                if (Arrays.asList(arr).contains("Uca")) {
                    UcaList.add(currentPeriodRingRatioList.get(i).getUca());
                    UcaListOne.add(lastPeriodRingRatioList.get(i).getUca());
                }
                if (Arrays.asList(arr).contains("Uc")) {
                    UcList.add(currentPeriodRingRatioList.get(i).getUc());
                    UcListOne.add(lastPeriodRingRatioList.get(i).getUc());
                }
                if (Arrays.asList(arr).contains("UblU2")) {
                    UblU2List.add(currentPeriodRingRatioList.get(i).getUblU2());
                    UblU2ListOne.add(lastPeriodRingRatioList.get(i).getUblU2());
                }
                if (Arrays.asList(arr).contains("UblU0")) {
                    UblU0List.add(currentPeriodRingRatioList.get(i).getUblU0());
                    UblU0ListOne.add(lastPeriodRingRatioList.get(i).getUblU0());
                }
                if (Arrays.asList(arr).contains("Ubc")) {
                    UbcList.add(currentPeriodRingRatioList.get(i).getUbc());
                    UbcListOne.add(lastPeriodRingRatioList.get(i).getUbc());
                }
                if (Arrays.asList(arr).contains("Ub")) {
                    UbList.add(currentPeriodRingRatioList.get(i).getUb());
                    UbListOne.add(lastPeriodRingRatioList.get(i).getUb());
                }
                if (Arrays.asList(arr).contains("Uab")) {
                    UabList.add(currentPeriodRingRatioList.get(i).getUab());
                    UabListOne.add(lastPeriodRingRatioList.get(i).getUab());
                }
                if (Arrays.asList(arr).contains("Ua")) {
                    UaList.add(currentPeriodRingRatioList.get(i).getUa());
                    UaListOne.add(lastPeriodRingRatioList.get(i).getUa());
                }
                if (Arrays.asList(arr).contains("THDUc")) {
                    THDUcList.add(currentPeriodRingRatioList.get(i).getTHDUc());
                    THDUcListOne.add(lastPeriodRingRatioList.get(i).getTHDUc());
                }
                if (Arrays.asList(arr).contains("THDUb")) {
                    THDUbList.add(currentPeriodRingRatioList.get(i).getTHDUb());
                    THDUbListOne.add(lastPeriodRingRatioList.get(i).getTHDUb());
                }
                if (Arrays.asList(arr).contains("THDUa")) {
                    THDUaList.add(currentPeriodRingRatioList.get(i).getTHDUa());
                    THDUaListOne.add(lastPeriodRingRatioList.get(i).getTHDUa());
                }
                if (Arrays.asList(arr).contains("T4")) {
                    T4List.add(currentPeriodRingRatioList.get(i).getT4());
                    T4ListOne.add(lastPeriodRingRatioList.get(i).getT4());
                }
                if (Arrays.asList(arr).contains("T3")) {
                    T3List.add(currentPeriodRingRatioList.get(i).getT3());
                    T3ListOne.add(lastPeriodRingRatioList.get(i).getT3());
                }
                if (Arrays.asList(arr).contains("T2")) {
                    T2List.add(currentPeriodRingRatioList.get(i).getT2());
                    T2ListOne.add(lastPeriodRingRatioList.get(i).getT2());
                }
                if (Arrays.asList(arr).contains("T1")) {
                    T1List.add(currentPeriodRingRatioList.get(i).getT1());
                    T1ListOne.add(lastPeriodRingRatioList.get(i).getT1());
                }
                if (Arrays.asList(arr).contains("SignalIntensity")) {
                    SignalIntensityList.add(currentPeriodRingRatioList.get(i).getSignalIntensity());
                    SignalIntensityListOne.add(lastPeriodRingRatioList.get(i).getSignalIntensity());
                }
                if (Arrays.asList(arr).contains("Qc")) {
                    QcList.add(currentPeriodRingRatioList.get(i).getQc());
                    QcListOne.add(lastPeriodRingRatioList.get(i).getQc());
                }
                if (Arrays.asList(arr).contains("Qb")) {
                    QbList.add(currentPeriodRingRatioList.get(i).getQb());
                    QbListOne.add(lastPeriodRingRatioList.get(i).getQb());
                }
                if (Arrays.asList(arr).contains("Qa")) {
                    QaList.add(currentPeriodRingRatioList.get(i).getQa());
                    QaListOne.add(lastPeriodRingRatioList.get(i).getQa());
                }
                if (Arrays.asList(arr).contains("Q")) {
                    QList.add(currentPeriodRingRatioList.get(i).getQ());
                    QListOne.add(lastPeriodRingRatioList.get(i).getQ());
                }
                if (Arrays.asList(arr).contains("Pc")) {
                    PcList.add(currentPeriodRingRatioList.get(i).getPc());
                    PcListOne.add(lastPeriodRingRatioList.get(i).getPc());
                }
                if (Arrays.asList(arr).contains("Pb")) {
                    PbList.add(currentPeriodRingRatioList.get(i).getPb());
                    PbListOne.add(lastPeriodRingRatioList.get(i).getPb());
                }
                if (Arrays.asList(arr).contains("Pa")) {
                    PaList.add(currentPeriodRingRatioList.get(i).getPa());
                    PaListOne.add(lastPeriodRingRatioList.get(i).getPa());
                }
                if (Arrays.asList(arr).contains("P")) {
                    PList.add(currentPeriodRingRatioList.get(i).getP());
                    PListOne.add(lastPeriodRingRatioList.get(i).getP());
                }
                if (Arrays.asList(arr).contains("LastDayMDt")) {
                    LastDayMDtList.add(currentPeriodRingRatioList.get(i).getLastDayMDt());
                    LastDayMDtListOne.add(lastPeriodRingRatioList.get(i).getLastDayMDt());
                }
                if (Arrays.asList(arr).contains("LastDayMD")) {
                    LastDayMDList.add(currentPeriodRingRatioList.get(i).getLastDayMD());
                    LastDayMDListOne.add(lastPeriodRingRatioList.get(i).getLastDayMD());
                }
                if (Arrays.asList(arr).contains("Ir")) {
                    IrList.add(currentPeriodRingRatioList.get(i).getIr());
                    IrListOne.add(lastPeriodRingRatioList.get(i).getIr());
                }
                if (Arrays.asList(arr).contains("Ic")) {
                    IcList.add(currentPeriodRingRatioList.get(i).getIc());
                    IcListOne.add(lastPeriodRingRatioList.get(i).getIc());
                }
                if (Arrays.asList(arr).contains("Ib")) {
                    IbList.add(currentPeriodRingRatioList.get(i).getIb());
                    IbListOne.add(lastPeriodRingRatioList.get(i).getIb());
                }
                if (Arrays.asList(arr).contains("Ia")) {
                    IaList.add(currentPeriodRingRatioList.get(i).getIa());
                    IaListOne.add(lastPeriodRingRatioList.get(i).getIa());
                }
                if (Arrays.asList(arr).contains("IHc")) {
                    IHcList.add(currentPeriodRingRatioList.get(i).getIHc());
                    IHcListOne.add(lastPeriodRingRatioList.get(i).getIHc());
                }
                if (Arrays.asList(arr).contains("IHb")) {
                    IHbList.add(currentPeriodRingRatioList.get(i).getIHb());
                    IHbListOne.add(lastPeriodRingRatioList.get(i).getIHb());
                }
                if (Arrays.asList(arr).contains("IHa")) {
                    IHaList.add(currentPeriodRingRatioList.get(i).getIHa());
                    IHaListOne.add(lastPeriodRingRatioList.get(i).getIHa());
                }
                if (Arrays.asList(arr).contains("I2")) {
                    I2List.add(currentPeriodRingRatioList.get(i).getI2());
                    I2ListOne.add(lastPeriodRingRatioList.get(i).getI2());
                }
                if (Arrays.asList(arr).contains("I0")) {
                    I0List.add(currentPeriodRingRatioList.get(i).getI0());
                    I0ListOne.add(lastPeriodRingRatioList.get(i).getI0());
                }
                if (Arrays.asList(arr).contains("F")) {
                    FList.add(currentPeriodRingRatioList.get(i).getF());
                    FListOne.add(lastPeriodRingRatioList.get(i).getF());
                }
                if (Arrays.asList(arr).contains("Eqp")) {
                    EqpList.add(currentPeriodRingRatioList.get(i).getEqp());
                    EqpListOne.add(lastPeriodRingRatioList.get(i).getEqp());
                }
                if (Arrays.asList(arr).contains("Eqn")) {
                    EqnList.add(currentPeriodRingRatioList.get(i).getEqn());
                    EqnListOne.add(lastPeriodRingRatioList.get(i).getEqn());
                }
                if (Arrays.asList(arr).contains("Epp4")) {
                    Epp4List.add(currentPeriodRingRatioList.get(i).getEpp4());
                    Epp4ListOne.add(lastPeriodRingRatioList.get(i).getEpp4());
                }
                if (Arrays.asList(arr).contains("Epp3")) {
                    Epp3List.add(currentPeriodRingRatioList.get(i).getEpp3());
                    Epp3ListOne.add(lastPeriodRingRatioList.get(i).getEpp3());
                }
                if (Arrays.asList(arr).contains("Epp2")) {
                    Epp2List.add(currentPeriodRingRatioList.get(i).getEpp2());
                    Epp2ListOne.add(lastPeriodRingRatioList.get(i).getEpp2());
                }
                if (Arrays.asList(arr).contains("Epp1")) {
                    Epp1List.add(currentPeriodRingRatioList.get(i).getEpp1());
                    Epp1ListOne.add(lastPeriodRingRatioList.get(i).getEpp1());
                }
                if (Arrays.asList(arr).contains("Epp")) {
                    EppList.add(currentPeriodRingRatioList.get(i).getEpp());
                    EppListOne.add(lastPeriodRingRatioList.get(i).getEpp());
                }
                if (Arrays.asList(arr).contains("Epn4")) {
                    Epn4List.add(currentPeriodRingRatioList.get(i).getEpn4());
                    Epn4ListOne.add(lastPeriodRingRatioList.get(i).getEpn4());
                }
                if (Arrays.asList(arr).contains("Epn3")) {
                    Epn3List.add(currentPeriodRingRatioList.get(i).getEpn3());
                    Epn3ListOne.add(lastPeriodRingRatioList.get(i).getEpn3());
                }
                if (Arrays.asList(arr).contains("Epn2")) {
                    Epn2List.add(currentPeriodRingRatioList.get(i).getEpn2());
                    Epn2ListOne.add(lastPeriodRingRatioList.get(i).getEpn2());
                }
                if (Arrays.asList(arr).contains("Epn1")) {
                    Epn1List.add(currentPeriodRingRatioList.get(i).getEpn1());
                    Epn1ListOne.add(lastPeriodRingRatioList.get(i).getEpn1());
                }
                if (Arrays.asList(arr).contains("Epn")) {
                    EpnList.add(currentPeriodRingRatioList.get(i).getEpn());
                    EpnListOne.add(lastPeriodRingRatioList.get(i).getEpn());
                }
                if (Arrays.asList(arr).contains("DeviceTemp")) {
                    DeviceTempList.add(currentPeriodRingRatioList.get(i).getDeviceTemp());
                    DeviceTempListOne.add(lastPeriodRingRatioList.get(i).getDeviceTemp());
                }
                if (Arrays.asList(arr).contains("DevResetTimes")) {
                    DevResetTimesList.add(currentPeriodRingRatioList.get(i).getDevResetTimes());
                    DevResetTimesListOne.add(lastPeriodRingRatioList.get(i).getDevResetTimes());
                }
                if (Arrays.asList(arr).contains("Demand")) {
                    DemandList.add(currentPeriodRingRatioList.get(i).getDemand());
                    DemandListOne.add(lastPeriodRingRatioList.get(i).getDemand());
                }
                if (Arrays.asList(arr).contains("COSc")) {
                    COScList.add(currentPeriodRingRatioList.get(i).getCOSc());
                    COScListOne.add(lastPeriodRingRatioList.get(i).getCOSc());
                }
                if (Arrays.asList(arr).contains("COSb")) {
                    COSbList.add(currentPeriodRingRatioList.get(i).getCOSb());
                    COSbListOne.add(lastPeriodRingRatioList.get(i).getCOSb());
                }
                if (Arrays.asList(arr).contains("COSa")) {
                    COSaList.add(currentPeriodRingRatioList.get(i).getCOSa());
                    COSaListOne.add(lastPeriodRingRatioList.get(i).getCOSa());
                }
                if (Arrays.asList(arr).contains("COS")) {
                    COSList.add(currentPeriodRingRatioList.get(i).getCos());
                    COSListOne.add(lastPeriodRingRatioList.get(i).getCos());
                }
            }
        }

        List<CommonIcoOneVO> list = new ArrayList<>();
//        list.add(CommonIcoOneVO.builder().name("底部时间").listDate(bottomTimeList).build());
        if (Arrays.asList(arr).contains("Busot")) {
            list.add(CommonIcoOneVO.builder().name("母线停电次数").currentPeriodList(BusotList).lastPeriodList(BusotListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COS")) {
            list.add(CommonIcoOneVO.builder().name("三相功率因数").currentPeriodList(COSList).lastPeriodList(COSListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSa")) {
            list.add(CommonIcoOneVO.builder().name("A相功率因数").currentPeriodList(COSaList).lastPeriodList(COSaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSb")) {
            list.add(CommonIcoOneVO.builder().name("B相功率因数").currentPeriodList(COSbList).lastPeriodList(COSbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("COSc")) {
            list.add(CommonIcoOneVO.builder().name("C相功率因数").currentPeriodList(COScList).lastPeriodList(COScListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Demand")) {
            list.add(CommonIcoOneVO.builder().name("实时有功需量").currentPeriodList(DemandList).lastPeriodList(DemandListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("DevResetTimes")) {
            list.add(CommonIcoOneVO.builder().name("设备复位次数").currentPeriodList(DevResetTimesList).lastPeriodList(DevResetTimesListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("DeviceTemp")) {
            list.add(CommonIcoOneVO.builder().name("设备温度").currentPeriodList(DeviceTempList).lastPeriodList(DeviceTempListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn")) {
            list.add(CommonIcoOneVO.builder().name("三相反向有功电度").currentPeriodList(EpnList).lastPeriodList(EpnListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn1")) {
            list.add(CommonIcoOneVO.builder().name("尖段反向有功电度").currentPeriodList(Epn1List).lastPeriodList(Epn1ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn2")) {
            list.add(CommonIcoOneVO.builder().name("峰段反向有功电度").currentPeriodList(Epn2List).lastPeriodList(Epn2ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn3")) {
            list.add(CommonIcoOneVO.builder().name("平段反向有功电度").currentPeriodList(Epn3List).lastPeriodList(Epn3ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epn4")) {
            list.add(CommonIcoOneVO.builder().name("谷段反向有功电度").currentPeriodList(Epn4List).lastPeriodList(Epn4ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp")) {
            list.add(CommonIcoOneVO.builder().name("三相正向有功电度").currentPeriodList(EppList).lastPeriodList(EppListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp1")) {
            list.add(CommonIcoOneVO.builder().name("尖段正向有功电度").currentPeriodList(Epp1List).lastPeriodList(Epp1ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp2")) {
            list.add(CommonIcoOneVO.builder().name("峰段正向有功电度").currentPeriodList(Epp2List).lastPeriodList(Epp2ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp3")) {
            list.add(CommonIcoOneVO.builder().name("平段正向有功电度").currentPeriodList(Epp3List).lastPeriodList(Epp3ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Epp4")) {
            list.add(CommonIcoOneVO.builder().name("谷段正向有功电度").currentPeriodList(Epp4List).lastPeriodList(Epp4ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Eqn")) {
            list.add(CommonIcoOneVO.builder().name("三相反向无功电度").currentPeriodList(EqnList).lastPeriodList(EqnListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Eqp")) {
            list.add(CommonIcoOneVO.builder().name("三相正向无功电度").currentPeriodList(EqpList).lastPeriodList(EqpListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("F")) {
            list.add(CommonIcoOneVO.builder().name("频率").currentPeriodList(FList).lastPeriodList(FListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("I0")) {
            list.add(CommonIcoOneVO.builder().name("零序电流").currentPeriodList(I0List).lastPeriodList(I0ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("I2")) {
            list.add(CommonIcoOneVO.builder().name("负序电流").currentPeriodList(I2List).lastPeriodList(I2ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHa")) {
            list.add(CommonIcoOneVO.builder().name("A相总谐波电流").currentPeriodList(IHaList).lastPeriodList(IHaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHb")) {
            list.add(CommonIcoOneVO.builder().name("B相总谐波电流").currentPeriodList(IHbList).lastPeriodList(IHbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("IHc")) {
            list.add(CommonIcoOneVO.builder().name("C相总谐波电流").currentPeriodList(IHcList).lastPeriodList(IHcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ia")) {
            list.add(CommonIcoOneVO.builder().name("A相电流").currentPeriodList(IaList).lastPeriodList(IaList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ib")) {
            list.add(CommonIcoOneVO.builder().name("B相电流").currentPeriodList(IbList).lastPeriodList(IbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ic")) {
            list.add(CommonIcoOneVO.builder().name("C相电流").currentPeriodList(IcList).lastPeriodList(IcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ir")) {
            list.add(CommonIcoOneVO.builder().name("剩余电流").currentPeriodList(IrList).lastPeriodList(IrListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("LastDayMD")) {
            list.add(CommonIcoOneVO.builder().name("昨日有功最大需量").currentPeriodList(LastDayMDList).lastPeriodList(LastDayMDListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("LastDayMDt")) {
            list.add(CommonIcoOneVO.builder().name("昨日有功最大需量发生时间").currentPeriodList(LastDayMDtList).lastPeriodList(LastDayMDtListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("P")) {
            list.add(CommonIcoOneVO.builder().name("三相总有功功率").currentPeriodList(PList).lastPeriodList(PList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pa")) {
            list.add(CommonIcoOneVO.builder().name("A相有功功率").currentPeriodList(PaList).lastPeriodList(PaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pb")) {
            list.add(CommonIcoOneVO.builder().name("B相有功功率").currentPeriodList(PbList).lastPeriodList(PbList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Pc")) {
            list.add(CommonIcoOneVO.builder().name("C相有功功率").currentPeriodList(PcList).lastPeriodList(PcList).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Q")) {
            list.add(CommonIcoOneVO.builder().name("三相总无功功率").currentPeriodList(QList).lastPeriodList(QListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qa")) {
            list.add(CommonIcoOneVO.builder().name("A相无功功率").currentPeriodList(QaList).lastPeriodList(QaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qb")) {
            list.add(CommonIcoOneVO.builder().name("B相无功功率").currentPeriodList(QbList).lastPeriodList(QbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Qc")) {
            list.add(CommonIcoOneVO.builder().name("C相无功功率").currentPeriodList(QcList).lastPeriodList(QcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("SignalIntensity")) {
            list.add(CommonIcoOneVO.builder().name("信号强度").currentPeriodList(SignalIntensityList).lastPeriodList(SignalIntensityListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T1")) {
            list.add(CommonIcoOneVO.builder().name("第1路温度").currentPeriodList(T1List).lastPeriodList(T1ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T2")) {
            list.add(CommonIcoOneVO.builder().name("第2路温度").currentPeriodList(T2List).lastPeriodList(T2ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T3")) {
            list.add(CommonIcoOneVO.builder().name("第3路温度").currentPeriodList(T3List).lastPeriodList(T3ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("T4")) {
            list.add(CommonIcoOneVO.builder().name("第4路温度").currentPeriodList(T4List).lastPeriodList(T4ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUa")) {
            list.add(CommonIcoOneVO.builder().name("A相电压THD").currentPeriodList(THDUaList).lastPeriodList(THDUaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUb")) {
            list.add(CommonIcoOneVO.builder().name("B相电压THD").currentPeriodList(THDUbList).lastPeriodList(THDUbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("THDUc")) {
            list.add(CommonIcoOneVO.builder().name("C相电压THD").currentPeriodList(THDUcList).lastPeriodList(THDUcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ua")) {
            list.add(CommonIcoOneVO.builder().name("A相电压").currentPeriodList(UaList).lastPeriodList(UaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uab")) {
            list.add(CommonIcoOneVO.builder().name("AB线电压").currentPeriodList(UabList).lastPeriodList(UabListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ub")) {
            list.add(CommonIcoOneVO.builder().name("B相电压").currentPeriodList(UbList).lastPeriodList(UbListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ubc")) {
            list.add(CommonIcoOneVO.builder().name("BC线电压").currentPeriodList(UbcList).lastPeriodList(UbcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("UblU0")) {
            list.add(CommonIcoOneVO.builder().name("零序电压不平衡度").currentPeriodList(UblU0List).lastPeriodList(UblU0ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("UblU2")) {
            list.add(CommonIcoOneVO.builder().name("负序电压不平衡度").currentPeriodList(UblU2List).lastPeriodList(UblU2ListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uc")) {
            list.add(CommonIcoOneVO.builder().name("C相电压").currentPeriodList(UcList).lastPeriodList(UcListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Uca")) {
            list.add(CommonIcoOneVO.builder().name("CA线电压").currentPeriodList(UcaList).lastPeriodList(UcaListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Udt")) {
            list.add(CommonIcoOneVO.builder().name("电压暂降次数").currentPeriodList(UdtList).lastPeriodList(UdtListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ul")) {
            list.add(CommonIcoOneVO.builder().name("线路侧电压").currentPeriodList(UlList).lastPeriodList(UlListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Upt")) {
            list.add(CommonIcoOneVO.builder().name("电压暂升次数").currentPeriodList(UptList).lastPeriodList(UptListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("freezingTime")) {
            list.add(CommonIcoOneVO.builder().name("电压短时中断次数").currentPeriodList(freezingTimesList).lastPeriodList(freezingTimesListOne).listDate(freezingTimesList).build());
        }
        if (Arrays.asList(arr).contains("Ust")) {
            list.add(CommonIcoOneVO.builder().name("冻结时间").currentPeriodList(UstList).lastPeriodList(UstListOne).listDate(freezingTimesList).build());
        }
        return list;
    }

    @Override
    public List<CommonIcoVO> monthlyReport(String deviceCode, int cycle, String startTime, String endTime) {
        List<Object> eppList = new ArrayList<>();
        List<Object> freezingTimesList = new ArrayList<>();
        List<HtAnalogDataVo> maxMonthlyReport = baseMapper.energyUseList(deviceCode, startTime, endTime, cycle, 1);
        List<HtAnalogDataVo> minMonthlyReport = baseMapper.energyUseList(deviceCode, startTime, endTime, cycle, 2);
        if (maxMonthlyReport.size() > 0) {
            for (int i = 0; i < maxMonthlyReport.size(); i++) {
                BigDecimal b1 = new BigDecimal(maxMonthlyReport.get(i).getEpp().toString());
                BigDecimal b2 = new BigDecimal(minMonthlyReport.get(i).getEpp().toString());
                eppList.add(b1.subtract(b2).doubleValue());
                freezingTimesList.add(maxMonthlyReport.get(i).getFreezingTimes());
            }
        }
        List<CommonIcoVO> list = new ArrayList<>();
        list.add(CommonIcoVO.builder().name("电量").list(eppList).listDate(freezingTimesList).build());
        return list;
    }

    @Override
    public List<CommonIcoVO> demandAnalysis(String deviceCode, String monthDate, int cycle) {
        List<Object> demandList = new ArrayList<>();
        List<Object> freezingTimesList = new ArrayList<>();
        List<HtAnalogDataVo> maxdemandAnalysis = baseMapper.demandAnalysisList(deviceCode, monthDate);
        for (int i = 0; i < maxdemandAnalysis.size(); i++){
            demandList.add(maxdemandAnalysis.get(i).getDemand());
            freezingTimesList.add(maxdemandAnalysis.get(i).getFreezingTimes());
        }
        List<CommonIcoVO> list = new ArrayList<>();
        list.add(CommonIcoVO.builder().name("实时有功需量").list(demandList).listDate(freezingTimesList).build());
        return list;
    }

}
